(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     79290,       1753]
NotebookOptionsPosition[     78660,       1728]
NotebookOutlinePosition[     79061,       1745]
CellTagsIndexPosition[     79018,       1742]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "This", " ", "produces", " ", "Figure", " ", "5", " ", "as", " ", 
      "shown", " ", "in", " ", "the", " ", "paper"}], ",", " ", 
     RowBox[{
     "and", " ", "writes", " ", "the", " ", "images", " ", "to", " ", "TIFF", 
      " ", "files"}]}], "  ", "*)"}], "Subsubtitle"], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"First", " ", "generate", " ", "the", " ", 
     RowBox[{"data", ".", " ", "The"}], " ", "numerical", " ", "integrations",
      " ", "may", " ", "take", " ", "a", " ", "few", " ", "minutes", " ", 
     "to", " ", "run"}], " ", "*)"}], "Subsubtitle"], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["y", "t"], "=", "0.1"}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "This", " ", "is", " ", "the", " ", "decision", " ", "threshold", " ", 
      "expressed", " ", "in", " ", "quantile", " ", 
      RowBox[{"terms", ".", " ", "If"}], " ", "this", " ", "parameter", " ", 
      "is", " ", "0.1"}], ",", " ", 
     RowBox[{
     "it", " ", "takes", " ", "the", " ", "top", " ", "10", "%", " ", "of", 
      " ", "the", " ", "distribution"}], ",", " ", 
     RowBox[{"if", " ", "it", " ", "is", " ", "0.01"}], ",", " ", 
     RowBox[{
     "it", " ", "takes", " ", "the", " ", "top", " ", "1", "%", " ", "of", 
      " ", "the", " ", "distribution"}], ",", " ", 
     RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"t", " ", "=", " ", 
     RowBox[{"Quantile", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}], ",", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         SubscriptBox["y", "t"]}], ")"}]}], "]"}]}], "  ", ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "convert", " ", "the", " ", "threshold", " ", "from", " ", "quantile", 
       " ", "units", " ", "to", " ", "standard", "  ", "deviation", " ", 
       "units", " ", "for", " ", "use", " ", "when", " ", "integrating", " ", 
       "the", " ", 
       RowBox[{"PDF", ".", " ", "Here"}], " ", "we", " ", "apply", " ", "the",
        " ", "same", " ", "threshold", " ", "to", " ", "each", " ", 
       "decision", " ", "variable", " ", "and", " ", "to", " ", "the", " ", 
       "reference", " ", "variable"}], ";", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"e", ".", "g", ".", " ", "if"}], " ", "yi"}], " ", 
       "\[GreaterEqual]", " ", "t"}]}], ",", " ", 
     RowBox[{"then", " ", "yi", " ", "is", " ", "a", " ", "yes"}], ",", " ", 
     RowBox[{
      RowBox[{"if", " ", "ri"}], " ", "\[GreaterEqual]", " ", "t"}], ",", " ", 
     RowBox[{"then", " ", "ri", " ", "is", " ", "a", " ", "positive"}]}], " ",
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "THE", " ", "NUMERICAL", " ", "INTEGRATIONS", " ", "HERE", " ", "CAN", 
     " ", "TAKE", " ", "A", " ", "FEW", " ", "MINUTES", " ", "TO", " ", 
     "RUN"}], " ", "*)"}], " ", "\[IndentingNewLine]", 
   RowBox[{"PPVvsTPRgraph", "=."}], "\[IndentingNewLine]", 
   RowBox[{"PPVvsNumScreenedgraph", "=."}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PPVvsTPRgraph", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "10", "}"}], ",", 
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PPVvsNumScreenedgraph", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "10", "}"}], ",", 
       RowBox[{"{", "4", "}"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "0"}], ",", 
     RowBox[{"i", "<", "10"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Rho]", "=", 
       RowBox[{"0.1", "*", "i"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "iterate", " ", "through", " ", "correlation", " ", "coefficient", " ",
         "parameters", " ", "from", " ", "0.0", " ", "to", " ", "0.9"}], " ", 
       "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "The", " ", "probability", " ", "mass", " ", "of", " ", "positives"}],
         ";", " ", 
        RowBox[{
         RowBox[{"items", " ", "where", " ", "r"}], " ", ">", " ", 
         RowBox[{"reference", " ", "threshold"}]}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"truepositive1", " ", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", "r"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Positives", " ", "that", " ", "cross", " ", "the", " ", "reference", 
        " ", 
        RowBox[{"threshold", ".", " ", "10"}], " ", "approvimates", " ", 
        "infinity", " ", "as", " ", "it", " ", "is", " ", "10", " ", 
        "standard", " ", "deviations", " ", "from", " ", "the", " ", "mean"}],
        " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "A", " ", "single", " ", "reference", " ", "variable", " ", "and", " ",
         "classification", " ", "step"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"truepositive2", " ", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"falsepositive2", "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"-", "10"}], ",", "t"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"2", " ", "classification", " ", "steps"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"truepositive3", " ", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "\[Rho]", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "1", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "\[Rho]", ",", "1"}], "}"}]}], "}"}]}],
             "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"falsepositive3", "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "\[Rho]", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "1", ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Rho]", ",", "\[Rho]", ",", "1"}], "}"}]}], "}"}]}],
             "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"-", "10"}], ",", "t"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"3", " ", "classification", " ", "steps"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"truepositive4", " ", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "1", ",", "\[Rho]", ",", " ", "\[Rho]", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "1", ",", " ", "\[Rho]", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "\[Rho]", ",", "1"}], 
                "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"falsepositive4", "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "1", ",", "\[Rho]", ",", " ", "\[Rho]", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "1", ",", " ", "\[Rho]", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", " ", "\[Rho]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "\[Rho]", ",", "1"}], 
                "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"-", "10"}], ",", "t"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"4", " ", "classification", " ", "steps"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"truepositive5", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "1", ",", "\[Rho]", ",", " ", "\[Rho]", ",", " ", "\[Rho]", 
                 ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "1", ",", "\[Rho]", ",", "\[Rho]", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", "\[Rho]", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", 
                 " ", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y", ",", "z", ",", "a"}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"falsepositive5", "=", " ", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{"PDF", "[", 
          RowBox[{
           RowBox[{"MultinormalDistribution", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "1", ",", "\[Rho]", ",", " ", "\[Rho]", ",", " ", "\[Rho]", 
                 ",", "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "1", ",", "\[Rho]", ",", "\[Rho]", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", "\[Rho]", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", " ", "1", ",", 
                 "\[Rho]"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", "\[Rho]", ",", 
                 " ", "1"}], "}"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "x", ",", "y", ",", "z", ",", "a"}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"-", "10"}], ",", "t"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "t", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"a", ",", "t", ",", "10"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "this", " ", "calculates", " ", "the", " ", "coordinates", " ", "for", 
        " ", "the", " ", "plot", " ", "of", " ", "PPV", " ", 
        RowBox[{"vs", ".", " ", "TPR"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PPVvsTPRgraph", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive2", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive2", " ", "+", " ", "falsepositive2"}], 
             ")"}]}], ",", 
           RowBox[{"truepositive2", "/", "truepositive1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive3", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive3", " ", "+", " ", "falsepositive3"}], 
             ")"}]}], ",", 
           RowBox[{"truepositive3", "/", "truepositive1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive4", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive4", " ", "+", " ", "falsepositive4"}], 
             ")"}]}], ",", 
           RowBox[{"truepositive4", "/", "truepositive1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive5", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive5", " ", "+", " ", "falsepositive5"}], 
             ")"}]}], ",", 
           RowBox[{"truepositive5", "/", "truepositive1"}]}], "}"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "this", " ", "calculates", " ", "the", " ", "coordinates", " ", "for", 
        " ", "the", " ", "plot", " ", "of", " ", "FDR", " ", "vs", " ", 
        "number", " ", "screened", " ", "per", " ", "positive", " ", 
        "identified"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PPVvsNumScreenedgraph", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive2", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive2", " ", "+", " ", "falsepositive2"}], 
             ")"}]}], ",", 
           RowBox[{"1", "/", "truepositive2"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive3", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive3", " ", "+", " ", "falsepositive3"}], 
             ")"}]}], ",", 
           RowBox[{"1", "/", "truepositive3"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive4", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive4", " ", "+", " ", "falsepositive4"}], 
             ")"}]}], ",", 
           RowBox[{"1", "/", "truepositive4"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"truepositive5", "/", 
            RowBox[{"(", 
             RowBox[{"truepositive5", " ", "+", " ", "falsepositive5"}], 
             ")"}]}], ",", 
           RowBox[{"1", "/", "truepositive5"}]}], "}"}]}], "}"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "write", " ", "the", " ", "results", " ", "to", " ", "excel", " ", 
     "files"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
     "\"\<Figure 5A Scannell&Bosley.xls\>\"", ",", " ", "PPVvsTPRgraph"}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{
     "\"\<Figure 5B Scannell&Bosley.xls\>\"", ",", " ", 
      "PPVvsNumScreenedgraph"}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6146987889205785`*^9, 3.61469879367385*^9}, {
   3.6146991988120227`*^9, 3.61469919963807*^9}, {3.6146992391353292`*^9, 
   3.6146992395073504`*^9}, 3.6146998022025347`*^9, 3.614739588161994*^9, {
   3.614739652226658*^9, 3.614739707516821*^9}, {3.6147398182621546`*^9, 
   3.6147398792206416`*^9}, {3.6147399711629004`*^9, 3.614740000842598*^9}, {
   3.614740040937891*^9, 3.6147400813302016`*^9}, {3.614740490503605*^9, 
   3.6147405211783595`*^9}, {3.614740565033868*^9, 3.614740565686905*^9}, 
   3.614740603313057*^9, {3.6147554922188797`*^9, 3.614755528392949*^9}, {
   3.614755618493102*^9, 3.614755630888811*^9}, {3.6147576751907387`*^9, 
   3.6147577013972373`*^9}, {3.6147587398696346`*^9, 3.614758741417723*^9}, {
   3.6330845213341494`*^9, 3.6330845303676662`*^9}, {3.6330849473575163`*^9, 
   3.633084978579302*^9}, {3.6330859834427767`*^9, 3.633085988372059*^9}, {
   3.6330865216665616`*^9, 3.6330865455819297`*^9}, {3.633087669653223*^9, 
   3.6330876774206667`*^9}, {3.633087953484457*^9, 3.6330879733665943`*^9}, 
   3.6380079957724648`*^9, {3.6380085551034565`*^9, 3.638008617806043*^9}, {
   3.638008713226501*^9, 3.638008722838051*^9}, {3.6380089514331255`*^9, 
   3.6380089662859755`*^9}, {3.6380089976567698`*^9, 
   3.6380090185179625`*^9}, {3.6380091127703533`*^9, 3.638009113893418*^9}, {
   3.638009657065486*^9, 3.638009813887455*^9}, {3.638010015692998*^9, 
   3.638010107574253*^9}, {3.6380101782612963`*^9, 3.638010220544715*^9}, {
   3.638010298883195*^9, 3.6380103085827503`*^9}, {3.638010366856083*^9, 
   3.638010377219676*^9}, {3.6380104169489484`*^9, 3.638010586420642*^9}, {
   3.6380116083560925`*^9, 3.6380116087351146`*^9}, {3.6380117026524863`*^9, 
   3.6380117170223083`*^9}, {3.638011807321473*^9, 3.6380118559212527`*^9}, {
   3.6380119530148067`*^9, 3.6380120117641664`*^9}, 3.638012074084731*^9, {
   3.638012188620282*^9, 3.6380122000229344`*^9}, 3.638012496696903*^9, {
   3.6380125875491*^9, 3.638012622381092*^9}, 3.6380126564340396`*^9, {
   3.6380126904249835`*^9, 3.638012691322035*^9}, {3.6380127226458263`*^9, 
   3.6380128378434153`*^9}, {3.638012872871419*^9, 3.6380129564221983`*^9}, {
   3.63801326731198*^9, 3.638013268563051*^9}, 3.6380142917705755`*^9, {
   3.638014571114553*^9, 3.6380147181739645`*^9}, {3.638014797838521*^9, 
   3.6380148020047593`*^9}, {3.6380149171943474`*^9, 3.638014928263981*^9}, {
   3.6380176158609767`*^9, 3.638017668680998*^9}, 3.638017813890303*^9, 
   3.6380178666623216`*^9, {3.6380179850050907`*^9, 3.6380179975188065`*^9}, {
   3.638018454464942*^9, 3.6380185254730034`*^9}, {3.6380187185040445`*^9, 
   3.638018722491272*^9}, {3.6380234801192384`*^9, 3.6380234811062946`*^9}, {
   3.6380875701170735`*^9, 3.6380876709408407`*^9}, 3.6380877166804566`*^9, {
   3.6380877566437426`*^9, 3.6380880450622387`*^9}, {3.638088080520267*^9, 
   3.6380882751604*^9}, {3.638088313699604*^9, 3.6380883692687826`*^9}, {
   3.6380885304189997`*^9, 3.638088537395399*^9}, {3.6380891802261667`*^9, 
   3.6380891846374187`*^9}, 3.6380893833127823`*^9, {3.6380894335436554`*^9, 
   3.638089455351903*^9}, {3.6497267294840198`*^9, 3.6497267564485617`*^9}, {
   3.6497268194111633`*^9, 3.649726820835245*^9}, {3.649728129116074*^9, 
   3.6497281811510506`*^9}, {3.649752706561824*^9, 3.649752707036851*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Draw", " ", "the", " ", "graphs", " ", "and", " ", "write", " ", "them", 
     " ", "to", " ", "TIFF", " ", "files"}], " ", "*)"}], "Subsubtitle"], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "load", " ", "functions", " ", "required", " ", "for", " ", "PlotLegend",
       " ", "use"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Fig5A", "=", 
     RowBox[{"ListLogPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "10", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "9", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "8", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "7", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "6", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "5", "]"}], "]"}], ",", 
         RowBox[{"PPVvsTPRgraph", "[", 
          RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
       RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<\!\(\*
StyleBox[\"PPV\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<\!\(\*
StyleBox[\"TPR\",
FontSlant->\"Italic\"]\)\>\""}], "}"}]}], ",", 
       RowBox[{"PlotLegend", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Rho]=0.9\>\"", ",", "\"\<\[Rho]=0.8\>\"", ",", 
          "\"\<\[Rho]=0.7\>\"", ",", "\"\<\[Rho]=0.6\>\"", ",", 
          "\"\<\[Rho]=0.5\>\"", ",", "\"\<\[Rho]=0.4\>\"", ",", 
          "\"\<\[Rho]=0.3\>\""}], "}"}]}], ",", 
       RowBox[{"LegendPosition", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.9", ",", 
          RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
       RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", " ", 
       RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0.18", ",", "0.93"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.01", ",", "1"}], "}"}]}], "}"}]}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Fig5B", "=", " ", 
    RowBox[{"ListLogPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "10", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "9", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "8", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "7", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "6", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "5", "]"}], "]"}], ",", 
        RowBox[{"PPVvsNumScreenedgraph", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
      RowBox[{"PlotMarkers", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*
StyleBox[\"PPV\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<Num. screened\>\""}], "}"}]}], ",", 
      RowBox[{"PlotLegend", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[Rho]=0.9\>\"", ",", "\"\<\[Rho]=0.8\>\"", ",", 
         "\"\<\[Rho]=0.7\>\"", ",", "\"\<\[Rho]=0.6\>\"", ",", 
         "\"\<\[Rho]=0.5\>\"", ",", "\"\<\[Rho]=0.4\>\"", ",", 
         "\"\<\[Rho]=0.3\>\""}], "}"}]}], ",", 
      RowBox[{"LegendPosition", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"0.9", ",", 
         RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
      RowBox[{"LegendShadow", "\[Rule]", "None"}], ",", " ", 
      RowBox[{"LegendBorder", "\[Rule]", "None"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "Medium"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.18", ",", "0.93"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"10", ",", "1000"}], "}"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<Figure 5A Scannell&Bosley.TIFF\>\"", ",", "Fig5A", ",", 
      RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<Figure 5B Scannell&Bosley.TIFF\>\"", ",", "Fig5B", ",", 
      RowBox[{"ImageResolution", "\[Rule]", "300"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6380195291994133`*^9, 3.6380195374198837`*^9}, {
  3.6380253959258165`*^9, 3.638025467470908*^9}, {3.6380255173457613`*^9, 
  3.638025542421195*^9}, {3.638088423638892*^9, 3.638088517433257*^9}, {
  3.638088568976205*^9, 3.6380885883393126`*^9}, {3.6380891919538374`*^9, 
  3.638089244414838*^9}, {3.6380892777927475`*^9, 3.638089298629939*^9}, {
  3.6497267691462884`*^9, 3.6497268051193457`*^9}, {3.6497273727108107`*^9, 
  3.6497273833164167`*^9}, {3.6497526199598703`*^9, 3.64975264268117*^9}, {
  3.649898678195075*^9, 3.6498986785830975`*^9}}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAHbEAeGoJ5j+ycsTPm9/Xv/nl96/m
O+o/VcEtMmRL4r9hmV239APsP2kVnFHgjOa/xGZ7FRv87D8nKUhysLvpv986
ZKNn/+E/qQPUAnFq4r8bbGdV3TbnPyPdNhnNr+y/VdcX/kSz6T/Re0cj5Nnx
v+pT+GBGIes/CZ7n1ih+9L/c/21mRPDdP7qlWbXCT+i/3gOYT0WG5D//8YZ+
+0Lzv49ghI2/eec/lxDs3dQ3+L/YK2uD70TpP71MGpoV//u/fUhX6p742D8V
7JGo/R3uv8SENaZW8eE/0r6mUr1Q+L/t+pnS+ivlPyr0Cxuo7P6/b39yK1BB
5z/mGChFEgQCwC32+IOqvNQ/OB1ICQwI8r/YJm0kJ8fePx+BmvGqvv2//MKx
o96z4j/aHiVFQisDwIXUykew/OQ/llQJHCyLBsBkZRIP6Q7RP/UjdRvvJ/W/
uF023bOq2T8KSAFTMeMBwISOc8YAAuA/SjWBwsFtB8DdipY/1l3iP8DwwPLQ
3gvAkvGjtEmryz+V9VDM5oH4v4nEDjefjtQ/7RMWnNBWBcD/IorFgxjaPyur
ChsahAzAvfZ0nHWT3j9Kr4BpcTYRwE7m8oo=
       "], {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[{1, 2, 3, 4}]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], LineBox[{5, 6, 7, 8}]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], LineBox[{9, 10, 11, 12}]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[{13, 14, 15, 16}]}, 
         {Hue[0.6142719099991583, 0.6, 0.6], LineBox[{17, 18, 19, 20}]}, 
         {Hue[0.8503398874989481, 0.6, 0.6], LineBox[{21, 22, 23, 24}]}, 
         {Hue[0.08640786499873876, 0.6, 0.6], LineBox[{25, 26, 27, 28}]}}, {
         {Hue[0.67, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 1], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 2], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 3], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 4]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 5], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 6], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 7], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 8]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 9], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 10], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 11], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 12]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 13], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 14], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 15], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 16]}, 
         {Hue[0.6142719099991583, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 17], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 18], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 19], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 20]}, 
         {Hue[0.8503398874989481, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 21], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 22], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 23], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 24]}, 
         {Hue[0.08640786499873876, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 25], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 26], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 27], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 28]}, {}}}], {}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesLabel->{
       FormBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"PPV\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
", TraditionalForm], 
       FormBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"TPR\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
", TraditionalForm]},
     AxesOrigin->{0.18, -4.605170185988091},
     CoordinatesToolOptions:>{"DisplayFunction" -> ({
         Part[#, 1], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Part[#, 1], 
         Exp[
          Part[#, 2]]}& )},
     DisplayFunction:>$DisplayFunction,
     FormatType->TraditionalForm,
     FrameTicks->{{{{-4.605170185988092, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-3.912023005428146, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.02\"", 0.02, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-2.995732273553991, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-2.302585092994046, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0., 
          FormBox[
           TagBox[
            InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {0.6931471805599453, 
          FormBox[
           TagBox[
            InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {1.6094379124341003`, 
          FormBox[
           TagBox[
            InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
            NumberForm[#, {
              DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
           TraditionalForm]}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.6592600369327783`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.2039728043259361`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{-4.605170185988092, 
          FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
          FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
          FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
          FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
          FormBox["\"\"", TraditionalForm]}, {0., 
          FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
          FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
          FormBox["\"\"", TraditionalForm]}, {-3.506557897319982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.6592600369327783`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.2039728043259361`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659907, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.35667494393873245`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}, {Automatic, Automatic}},
     GridLines->{None, None},
     ImageSize->Medium,
     Method->{},
     PlotRange->{{0.18, 0.93}, {-4.605170185988091, 0.}},
     PlotRangeClipping->True,
     PlotRangePadding->{{None, None}, {None, None}},
     Ticks->{Automatic, {{-4.605170185988092, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.02\"", 0.02, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-3.506557897319982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.6592600369327783`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.2039728043259361`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
     {GrayLevel[0], RectangleBox[{0.9, -0.4}, {1.2230769230769232`, 0.4}]}, 
     {GrayLevel[1], EdgeForm[None], 
      GraphicsGroupBox[{RectangleBox[{0.9, -0.4}, {1.2230769230769232`, 0.4}],
         InsetBox[
         GraphicsBox[{{{InsetBox[
              GraphicsBox[{
                {Hue[0.08640786499873698, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[EmptySquare]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.08640786499873698, 0.6, 0.6],
                  FrontFaceColor->Hue[0.08640786499873698, 0.6, 0.6],
                  BackFaceColor->Hue[0.08640786499873698, 0.6, 0.6],
                  GraphicsColor->Hue[0.08640786499873698, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.08640786499873698, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.3\"\>", {1.2100000000000002`, 0.58}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.8503398874989481, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[EmptyCircle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.8503398874989481, 0.6, 0.6],
                  FrontFaceColor->Hue[0.8503398874989481, 0.6, 0.6],
                  BackFaceColor->Hue[0.8503398874989481, 0.6, 0.6],
                  GraphicsColor->Hue[0.8503398874989481, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.8503398874989481, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.4\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.6142719099991583, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledDownTriangle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.6142719099991583, 0.6, 0.6],
                  FrontFaceColor->Hue[0.6142719099991583, 0.6, 0.6],
                  BackFaceColor->Hue[0.6142719099991583, 0.6, 0.6],
                  GraphicsColor->Hue[0.6142719099991583, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.6142719099991583, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.5\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.37820393249936846`, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledUpTriangle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  FrontFaceColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  BackFaceColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  GraphicsColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  FontSize->10.24,
                  
                  FontColor->Hue[
                   0.37820393249936846`, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 3.56}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.6\"\>", \
{1.2100000000000002`, 4.0600000000000005`}, {-1, 0}, Automatic, {1, 0}]}, {
             InsetBox[
              GraphicsBox[{
                {Hue[0.1421359549995791, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledDiamond]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.1421359549995791, 0.6, 0.6],
                  FrontFaceColor->Hue[0.1421359549995791, 0.6, 0.6],
                  BackFaceColor->Hue[0.1421359549995791, 0.6, 0.6],
                  GraphicsColor->Hue[0.1421359549995791, 0.6, 0.6],
                  FontSize->10.88,
                  FontColor->Hue[0.1421359549995791, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 4.72}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.7\"\>", {1.2100000000000002`, 5.22}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.9060679774997897, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledSquare]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.9060679774997897, 0.6, 0.6],
                  FrontFaceColor->Hue[0.9060679774997897, 0.6, 0.6],
                  BackFaceColor->Hue[0.9060679774997897, 0.6, 0.6],
                  GraphicsColor->Hue[0.9060679774997897, 0.6, 0.6],
                  FontSize->8.96,
                  FontColor->Hue[0.9060679774997897, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 5.88}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.8\"\>", {1.2100000000000002`, 6.38}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledCircle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.67, 0.6, 0.6],
                  FrontFaceColor->Hue[0.67, 0.6, 0.6],
                  BackFaceColor->Hue[0.67, 0.6, 0.6],
                  GraphicsColor->Hue[0.67, 0.6, 0.6],
                  FontSize->8.96,
                  FontColor->Hue[0.67, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 7.04}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.9\"\>", {1.2100000000000002`, 7.54}, {-1, 0},
               Automatic, {1, 0}]}}, {}},
          AspectRatio->2.476190476190476,
          FormatType->TraditionalForm,
          
          PlotRange->{{-0.1, 3.26}, {-0.1, 
           8.219999999999999}}], {0.9, -0.4}, {
         Left, Bottom}, {0.32307692307692315`, 0.8}]}]}}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Medium,
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.6380177114124417`*^9, 3.6380195447393017`*^9, 3.6380252832853737`*^9, {
   3.63802542815866*^9, 3.6380254700220547`*^9}, {3.638025521611005*^9, 
   3.63802554688245*^9}, {3.6380891709256344`*^9, 3.6380892181823378`*^9}, 
   3.6380892486190786`*^9, 3.6497280502895656`*^9, 3.649729002678039*^9, 
   3.6497296786577024`*^9, 3.6497526534217844`*^9}],

Cell[BoxData[
 GraphicsBox[{InsetBox[
    GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJwB0QEu/iFib1JlAgAAABwAAAACAAAAHbEAeGoJ5j8m4601pWcFQPnl96/m
O+o/JcVAyIr+BkBhmV239APsPypaHNDpDghAxGZ7FRv87D8ZX0fYndoIQN86
ZKNn/+E/ulVq/E0GB0AbbGdV3TbnPxgMAwKllwlAVdcX/kSz6T+4ElnNo1gL
QOpT+GBGIes/1CMpJ8aqDEDc/21mRPDdPz6+C2mifwhA3gOYT0WG5D/Pzfh6
Lw0MQI9ghI2/eec/G12rKpyHDkDYK2uD70TpP5c9YUSeNRBAfUhX6p742D/V
z9klMfMJQMSENaZW8eE/OLQIZRCUDkDt+pnS+ivlP3KnneQC8RBAb39yK1BB
5z/btm4A4jcSQC32+IOqvNQ/bGNZwLdvC0DYJm0kJ8feP69KQZqDpRBA/MKx
o96z4j/VOW0AessSQIXUykew/OQ/s1Tf6257FEBkZRIP6Q7RP8rmb0mp/wxA
uF023bOq2T9tTluHcScSQISOc8YAAuA/DUUbv7nsFEDdipY/1l3iP8giO1dB
JRdAkvGjtEmryz+az90hpawOQInEDjefjtQ/XrTlK0HhE0D/IorFgxjaP/3/
X+vldxdAvfZ0nHWT3j+yWVtHSmwaQBCQ1mo=
       "], {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[{1, 2, 3, 4}]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], LineBox[{5, 6, 7, 8}]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], LineBox[{9, 10, 11, 12}]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[{13, 14, 15, 16}]}, 
         {Hue[0.6142719099991583, 0.6, 0.6], LineBox[{17, 18, 19, 20}]}, 
         {Hue[0.8503398874989481, 0.6, 0.6], LineBox[{21, 22, 23, 24}]}, 
         {Hue[0.08640786499873876, 0.6, 0.6], LineBox[{25, 26, 27, 28}]}}, {
         {Hue[0.67, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 1], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 2], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 3], InsetBox[
           StyleBox["\<\"\[FilledCircle]\"\>",
            StripOnInput->False,
            FontSize->8.96], 4]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 5], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 6], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 7], InsetBox[
           StyleBox["\<\"\[FilledSquare]\"\>",
            StripOnInput->False,
            FontSize->8.96], 8]}, 
         {Hue[0.1421359549995791, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 9], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 10], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 11], InsetBox[
           StyleBox["\<\"\[FilledDiamond]\"\>",
            StripOnInput->False,
            FontSize->10.88], 12]}, 
         {Hue[0.37820393249936934`, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 13], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 14], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 15], InsetBox[
           StyleBox["\<\"\[FilledUpTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 16]}, 
         {Hue[0.6142719099991583, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 17], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 18], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 19], InsetBox[
           StyleBox["\<\"\[FilledDownTriangle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 20]}, 
         {Hue[0.8503398874989481, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 21], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 22], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 23], InsetBox[
           StyleBox["\<\"\[EmptyCircle]\"\>",
            StripOnInput->False,
            FontSize->10.24], 24]}, 
         {Hue[0.08640786499873876, 0.6, 0.6], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 25], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 26], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 27], InsetBox[
           StyleBox["\<\"\[EmptySquare]\"\>",
            StripOnInput->False,
            FontSize->10.24], 28]}, {}}}], {}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->True,
     AxesLabel->{
       FormBox[
       "\"\\!\\(\\*\\nStyleBox[\\\"PPV\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
", TraditionalForm], 
       FormBox["\"Num. screened\"", TraditionalForm]},
     AxesOrigin->{0.18, 2.302585092994046},
     CoordinatesToolOptions:>{"DisplayFunction" -> ({
         Part[#, 1], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Part[#, 1], 
         Exp[
          Part[#, 2]]}& )},
     DisplayFunction:>$DisplayFunction,
     FormatType->TraditionalForm,
     FrameTicks->{{{{2.302585092994046, 
          FormBox["10", TraditionalForm]}, {2.995732273553991, 
          FormBox["20", TraditionalForm]}, {3.912023005428146, 
          FormBox["50", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {5.298317366548036, 
          FormBox["200", TraditionalForm]}, {6.214608098422191, 
          FormBox["500", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {7.600902459542082, 
          FormBox["2000", TraditionalForm]}, {8.517193191416238, 
          FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, {{2.302585092994046, 
          FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
          FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
          FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
          FormBox["\"\"", TraditionalForm]}, {5.298317366548036, 
          FormBox["\"\"", TraditionalForm]}, {6.214608098422191, 
          FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
          FormBox["\"\"", TraditionalForm]}, {7.600902459542082, 
          FormBox["\"\"", TraditionalForm]}, {8.517193191416238, 
          FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.006367567650246, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {8.294049640102028, 
          FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}}, {Automatic, Automatic}},
     GridLines->{None, None},
     ImageSize->Medium,
     Method->{},
     PlotRange->{{0.18, 0.93}, {2.302585092994046, 6.907755278982137}},
     PlotRangeClipping->True,
     PlotRangePadding->{{None, None}, {None, None}},
     Ticks->{Automatic, {{2.302585092994046, 
         FormBox["10", TraditionalForm]}, {2.995732273553991, 
         FormBox["20", TraditionalForm]}, {3.912023005428146, 
         FormBox["50", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {5.298317366548036, 
         FormBox["200", TraditionalForm]}, {6.214608098422191, 
         FormBox["500", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {7.600902459542082, 
         FormBox["2000", TraditionalForm]}, {8.517193191416238, 
         FormBox["5000", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.006367567650246, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {8.294049640102028, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}], {-1, -0.6180339887498948}, {
    Left, Bottom}, {2, 1.2360679774997896`}], GraphicsGroupBox[{
     {GrayLevel[0], RectangleBox[{0.9, -0.4}, {1.2230769230769232`, 0.4}]}, 
     {GrayLevel[1], EdgeForm[None], 
      GraphicsGroupBox[{RectangleBox[{0.9, -0.4}, {1.2230769230769232`, 0.4}],
         InsetBox[
         GraphicsBox[{{{InsetBox[
              GraphicsBox[{
                {Hue[0.08640786499873698, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[EmptySquare]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.08640786499873698, 0.6, 0.6],
                  FrontFaceColor->Hue[0.08640786499873698, 0.6, 0.6],
                  BackFaceColor->Hue[0.08640786499873698, 0.6, 0.6],
                  GraphicsColor->Hue[0.08640786499873698, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.08640786499873698, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 0.08}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.3\"\>", {1.2100000000000002`, 0.58}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.8503398874989481, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[EmptyCircle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.8503398874989481, 0.6, 0.6],
                  FrontFaceColor->Hue[0.8503398874989481, 0.6, 0.6],
                  BackFaceColor->Hue[0.8503398874989481, 0.6, 0.6],
                  GraphicsColor->Hue[0.8503398874989481, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.8503398874989481, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 1.24}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.4\"\>", {1.2100000000000002`, 1.74}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.6142719099991583, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledDownTriangle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.6142719099991583, 0.6, 0.6],
                  FrontFaceColor->Hue[0.6142719099991583, 0.6, 0.6],
                  BackFaceColor->Hue[0.6142719099991583, 0.6, 0.6],
                  GraphicsColor->Hue[0.6142719099991583, 0.6, 0.6],
                  FontSize->10.24,
                  FontColor->Hue[0.6142719099991583, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 2.4}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.5\"\>", {1.2100000000000002`, 2.9}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.37820393249936846`, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledUpTriangle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  FrontFaceColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  BackFaceColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  GraphicsColor->Hue[0.37820393249936846`, 0.6, 0.6],
                  FontSize->10.24,
                  
                  FontColor->Hue[
                   0.37820393249936846`, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 3.56}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.6\"\>", \
{1.2100000000000002`, 4.0600000000000005`}, {-1, 0}, Automatic, {1, 0}]}, {
             InsetBox[
              GraphicsBox[{
                {Hue[0.1421359549995791, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledDiamond]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.1421359549995791, 0.6, 0.6],
                  FrontFaceColor->Hue[0.1421359549995791, 0.6, 0.6],
                  BackFaceColor->Hue[0.1421359549995791, 0.6, 0.6],
                  GraphicsColor->Hue[0.1421359549995791, 0.6, 0.6],
                  FontSize->10.88,
                  FontColor->Hue[0.1421359549995791, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 4.72}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.7\"\>", {1.2100000000000002`, 5.22}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.9060679774997897, 0.6, 0.6], 
                 LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledSquare]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.9060679774997897, 0.6, 0.6],
                  FrontFaceColor->Hue[0.9060679774997897, 0.6, 0.6],
                  BackFaceColor->Hue[0.9060679774997897, 0.6, 0.6],
                  GraphicsColor->Hue[0.9060679774997897, 0.6, 0.6],
                  FontSize->8.96,
                  FontColor->Hue[0.9060679774997897, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 5.88}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.8\"\>", {1.2100000000000002`, 6.38}, {-1, 0},
               Automatic, {1, 0}]}, {InsetBox[
              GraphicsBox[{
                {Hue[0.67, 0.6, 0.6], LineBox[{{0, 0.5}, {1, 0.5}}]}, InsetBox[
                 StyleBox["\<\"\[FilledCircle]\"\>",
                  StripOnInput->False,
                  LineColor->Hue[0.67, 0.6, 0.6],
                  FrontFaceColor->Hue[0.67, 0.6, 0.6],
                  BackFaceColor->Hue[0.67, 0.6, 0.6],
                  GraphicsColor->Hue[0.67, 0.6, 0.6],
                  FontSize->8.96,
                  FontColor->Hue[0.67, 0.6, 0.6]], {0.5, 0.5}]},
               PlotRange->{{0, 1}, {0, 1}}], {0.08, 7.04}, {
              Left, Bottom}, {1, 1}], 
             InsetBox["\<\"\[Rho]=0.9\"\>", {1.2100000000000002`, 7.54}, {-1, 0},
               Automatic, {1, 0}]}}, {}},
          AspectRatio->2.476190476190476,
          FormatType->TraditionalForm,
          
          PlotRange->{{-0.1, 3.26}, {-0.1, 
           8.219999999999999}}], {0.9, -0.4}, {
         Left, Bottom}, {0.32307692307692315`, 0.8}]}]}}]},
  AspectRatio->Automatic,
  Background->None,
  ColorOutput->Automatic,
  ImageSize->Medium,
  PlotRange->All]], "Output",
 CellChangeTimes->{
  3.6380177114124417`*^9, 3.6380195447393017`*^9, 3.6380252832853737`*^9, {
   3.63802542815866*^9, 3.6380254700220547`*^9}, {3.638025521611005*^9, 
   3.63802554688245*^9}, {3.6380891709256344`*^9, 3.6380892181823378`*^9}, 
   3.6380892486190786`*^9, 3.6497280502895656`*^9, 3.649729002678039*^9, 
   3.6497296786577024`*^9, 3.649752656373953*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{
    "Show", " ", "the", " ", "raw", " ", "results", " ", "data", " ", "for", 
     " ", "correlations", " ", "from", " ", "0.0", " ", "to", " ", "0.9", " ",
      "with", " ", "rows", " ", "in", " ", "order", " ", "of", " ", 
     "ascending", " ", "correlation"}], " ", "*)"}], "Subsubtitle"], 
  "\[IndentingNewLine]", 
  RowBox[{
  "PPVvsTPRgraph", "\[IndentingNewLine]", 
   "PPVvsNumScreenedgraph"}]}]], "Input",
 CellChangeTimes->{{3.638089318865096*^9, 3.6380893462446623`*^9}, {
  3.6497280989063463`*^9, 3.6497281005894423`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.09999999968515816`", ",", "0.10000000690188551`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.09999999900861203`", ",", "0.009999999856613127`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.09999996828367942`", ",", "0.000999999487229632`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.09999993955513657`", ",", "0.0000999998363078571`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.1333544093783012`", ",", "0.13335440798057285`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.1673688298772449`", ",", "0.022319371023222585`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.2010685416881681`", ",", "0.004487722285688087`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.23382987607083766`", ",", "0.0010493595513797482`"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.17196254916387377`", ",", "0.17196254862904423`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.24249975619463032`", ",", "0.04170086955889086`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3069936131083302`", ",", "0.012801894600806583`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.36427921354588066`", ",", "0.004663467656057334`"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.21616479225475566`", ",", "0.21616478970800165`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3212049520180434`", ",", "0.06943320421762722`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.4077462605569479`", ",", "0.02831105491586832`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.4777502086543384`", ",", "0.01352565525270472`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.26653505775319375`", ",", "0.2665350525321645`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.40104385950823085`", ",", "0.10689225416581496`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.5002445102695252`", ",", "0.05347226216636901`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.5739547006563402`", ",", "0.03069065786804117`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.32401526344242165`", ",", "0.3240152800451007`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.48090532834303934`", ",", "0.15582062961571955`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.5844567486911667`", ",", "0.0910703955608754`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.655845775813433`", ",", "0.05972794808637164`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.3901746071325148`", ",", "0.390174582397437`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5607102628965994`", ",", "0.21877492828866726`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.6616186250028854`", ",", "0.14474560791551586`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.7267227982119787`", ",", "0.10518990193125287`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.4677897453584572`", ",", "0.46778972064992885`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.6413904718939383`", ",", "0.3000359059902305`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7336118473058536`", ",", "0.2201093655412561`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7896649901170987`", ",", "0.1738127931132829`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5624273482552232`", ",", "0.5624273318946991`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7254473369642968`", ",", "0.40801142469350554`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8031334841495928`", ",", "0.3276871014846819`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.847811879534331`", ",", "0.27781477445154057`"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.6886494010737213`", ",", "0.6886494018366929`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8198121487504856`", ",", "0.5645631399057517`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8754829007491872`", ",", "0.4942584070900534`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9057746333666832`", ",", "0.44746306336338404`"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.6380177114124417`*^9, 3.6380195447393017`*^9, 3.6380252832853737`*^9, {
   3.63802542815866*^9, 3.6380254700220547`*^9}, {3.638025521611005*^9, 
   3.63802554688245*^9}, {3.6380891709256344`*^9, 3.6380892181823378`*^9}, 
   3.638089251182225*^9, 3.6380893037952347`*^9, 3.6380893503228955`*^9, {
   3.6497280940440683`*^9, 3.6497281093979464`*^9}}],

Cell[BoxData["PPVvsNumScreenedgraph"], "Output",
 CellChangeTimes->{
  3.6380177114124417`*^9, 3.6380195447393017`*^9, 3.6380252832853737`*^9, {
   3.63802542815866*^9, 3.6380254700220547`*^9}, {3.638025521611005*^9, 
   3.63802554688245*^9}, {3.6380891709256344`*^9, 3.6380892181823378`*^9}, 
   3.638089251182225*^9, 3.6380893037952347`*^9, 3.6380893503228955`*^9, {
   3.6497280940440683`*^9, 3.6497281094009466`*^9}}]
}, Open  ]]
},
WindowSize->{705, 805},
WindowMargins->{{Automatic, 70}, {Automatic, -29}},
ShowSelection->True,
Magnification->0.7999999523162842,
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 23926, 551, 1351, "Input"],
Cell[CellGroupData[{
Cell[24508, 575, 5591, 130, 365, "Input"],
Cell[30102, 707, 23017, 470, 171, "Output"],
Cell[53122, 1179, 19444, 378, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72603, 1562, 610, 14, 76, "Input"],
Cell[73216, 1578, 5004, 139, 159, "Output"],
Cell[78223, 1719, 421, 6, 23, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
